@@ -2,7 +2,8 @@
                           type = c("free", "series", "grid", "strata"),
                           maxperm = 9999, minperm = 99,
                           mirror = FALSE, constant = FALSE,
-                          ncol = NULL, nrow = NULL)
+                          ncol = NULL, nrow = NULL,
+                          all.perms = NULL)
 {
     if(missing(type))
         type <- "free"
@@ -12,7 +13,7 @@
                 type = type,
                 maxperm = maxperm, minperm = minperm,
                 mirror = mirror, constant = constant,
-                ncol = ncol, nrow = nrow,
+                ncol = ncol, nrow = nrow, all.perms = all.perms,
                 name.strata = deparse(substitute(strata)))
     class(out) <- "permControl"
     return(out)
